Type Alias Approvals

pub type Approvals<T: Config<I>, I: 'static = ()> = StorageValue<_GeneratedPrefixForStorageApprovals<T, I>, BoundedVec<ProposalIndex, T::MaxApprovals>, ValueQuery>;
DEPRECATED: associated with spend_local call and will be removed in May 2025. Refer to https://github.com/paritytech/polkadot-sdk/pull/5961 for migration to spend.

Proposal indices that have been approved but not yet awarded.

Storage type is StorageValue with value type BoundedVec < ProposalIndex, T :: MaxApprovals >.

Aliased Type

pub struct Approvals<T: Config<I>, I: 'static = ()>(/* private fields */);